"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CyberConnectConnector = void 0;
const providers_1 = require("@ethersproject/providers");
const cyber_app_sdk_1 = require("@cyberlab/cyber-app-sdk");
const events_1 = require("events");
const ARBITRUM_CHAIN_ID = 42161;
class CyberConnectConnector extends events_1.EventEmitter {
    constructor(args) {
        super();
        this.isActivationInProgress = false;
        this.autoConnect = async () => {
            await this.calcAccountData();
        };
        this.disconnect = () => {
            this.account = undefined;
        };
        this.connect = async () => {
            await this.calcAccountData();
        };
        this.switchChain = async (chainId) => {
            return this.calcAccountData(chainId);
        };
        this.addChain = () => {
            console.warn('Method addChain not allowed');
            return null;
        };
        this.addToken = () => {
            console.warn('Method addToken not allowed');
            return null;
        };
        this.name = args.name;
        this.icon = args.icon;
        this.installed = args.installed;
        this.calcAccountData();
    }
    async calcAccountData(currentChainId = ARBITRUM_CHAIN_ID) {
        const cyberApp = new cyber_app_sdk_1.CyberApp({
            appId: 'jumper.exchange',
            name: 'Jumper.Exchange',
            icon: 'https://raw.githubusercontent.com/lifinance/jumper.exchange/e9ead2e32981db0bf47adf2b1b2781e31ad14650/packages/dapp/public/logo-144x144.svg',
        });
        const cyberProvider = new cyber_app_sdk_1.CyberProvider({
            app: cyberApp,
            chainId: currentChainId,
        });
        const provider = new providers_1.Web3Provider(cyberProvider, 'any');
        const signer = provider.getSigner();
        this.account = {
            chainId: currentChainId,
            address: await signer.getAddress(),
            signer,
            provider,
            isMultisigWallet: true,
        };
        this.emit('walletAccountChanged', this);
    }
}
exports.CyberConnectConnector = CyberConnectConnector;
