"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SafeWalletConnector = void 0;
const providers_1 = require("@ethersproject/providers");
const safe_apps_provider_1 = require("@safe-global/safe-apps-provider");
const safe_apps_sdk_1 = require("@safe-global/safe-apps-sdk");
const events_1 = require("events");
class SafeWalletConnector extends events_1.EventEmitter {
    constructor(args) {
        super();
        this.isActivationInProgress = false;
        this.autoConnect = async () => {
            await this.calcAccountData();
        };
        this.disconnect = () => {
            this.account = undefined;
        };
        this.connect = async () => {
            await this.calcAccountData();
        };
        this.switchChain = () => {
            console.warn('Method switchChain not allowed');
            return null;
        };
        this.addChain = () => {
            console.warn('Method addChain not allowed');
            return null;
        };
        this.addToken = () => {
            console.warn('Method addToken not allowed');
            return null;
        };
        this.name = args.name;
        this.icon = args.icon;
        this.installed = args.installed;
        this.calcAccountData();
    }
    async calcAccountData() {
        const sdk = new safe_apps_sdk_1.default();
        const accountInfo = await sdk.safe.getInfo();
        const safe = {
            safeAddress: accountInfo.safeAddress,
            chainId: accountInfo.chainId,
            threshold: accountInfo.threshold,
            owners: accountInfo.owners,
            isReadOnly: accountInfo.isReadOnly,
        };
        const safeInstance = new safe_apps_provider_1.SafeAppProvider(safe, sdk);
        const provider = new providers_1.Web3Provider(safeInstance);
        const signer = provider.getSigner();
        this.account = {
            chainId: accountInfo.chainId,
            address: accountInfo.safeAddress,
            signer,
            provider,
            isMultisigWallet: true,
        };
        this.emit('walletAccountChanged', this);
    }
}
exports.SafeWalletConnector = SafeWalletConnector;
