"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WalletConnectConnector = void 0;
const providers_1 = require("@ethersproject/providers");
const ethereum_provider_1 = require("@walletconnect/ethereum-provider");
const events_1 = require("events");
const walletAutomation_1 = require("../walletAutomation");
class WalletConnectConnector extends events_1.EventEmitter {
    constructor(args) {
        super();
        this.isActivationInProgress = false;
        this.options = args.options;
        this.name = args.name;
        this.icon = args.icon;
        this.installed = args.installed;
    }
    async startListening() {
        // Subscribe to accounts change
        this.provider?.on('accountsChanged', async (accounts) => {
            if (!accounts.length) {
                this.account = undefined;
                this.emit('walletAccountChanged', this);
                return;
            }
            await this.calcAccountData();
        });
        // Subscribe to chainId change
        this.provider?.on('chainChanged', async (chainId) => {
            await this.calcAccountData();
        });
        // Subscribe to session disconnection
        this.provider?.on('disconnect', async (code, reason) => {
            // await this.calcAccountData();
        });
    }
    async connect() {
        if (this.isActivationInProgress) {
            return;
        }
        this.isActivationInProgress = true;
        this.walletConnectProvider || (this.walletConnectProvider = await ethereum_provider_1.default.init(this.options));
        this.provider = this
            .walletConnectProvider;
        try {
            // Open modal
            await this.walletConnectProvider?.enable();
            this.startListening();
            await this.calcAccountData();
        }
        catch (e) {
            this.isActivationInProgress = false;
            throw e;
        }
        this.isActivationInProgress = false;
    }
    async disconnect() {
        if (this.provider) {
            await this.provider?.disconnect();
            await this.walletConnectProvider?.disconnect();
            this.provider = undefined;
            this.walletConnectProvider = undefined;
            this.isActivationInProgress = false;
            this.account = undefined;
            this.emit('walletAccountChanged', this);
        }
    }
    async switchChain(chainId) {
        if (!this.provider) {
            throw new Error('Provider is not defined.');
        }
        return (0, walletAutomation_1.switchChain)(this.walletConnectProvider, chainId);
    }
    async addChain(chainId) {
        if (!this.provider) {
            throw new Error('Provider is not defined.');
        }
        return (0, walletAutomation_1.addChain)(this.walletConnectProvider, chainId);
    }
    async addToken(chainId, token) {
        if (!this.provider) {
            throw new Error('Provider is not defined.');
        }
        return (0, walletAutomation_1.switchChainAndAddToken)(this.walletConnectProvider, chainId, token);
    }
    async calcAccountData() {
        if (!this.walletConnectProvider) {
            throw new Error('Provider is not defined.');
        }
        const provider = new providers_1.Web3Provider(this.walletConnectProvider, 'any');
        const signer = provider.getSigner();
        this.account = {
            chainId: await signer.getChainId(),
            address: await signer.getAddress(),
            signer,
            provider,
        };
        this.emit('walletAccountChanged', this);
    }
}
exports.WalletConnectConnector = WalletConnectConnector;
