"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.switchChainAndAddToken = exports.addToken = exports.addChain = exports.switchChain = void 0;
const sdk_1 = require("@lifi/sdk");
const switchChain = async (provider, chainId) => {
    const params = { chainId: (0, sdk_1.getChainById)(chainId).metamask?.chainId };
    try {
        if (provider.send) {
            await provider.send('wallet_switchEthereumChain', [params]);
            return true;
        }
        else {
            const switched = await new Promise((resolve, reject) => {
                provider
                    .request({
                    method: 'wallet_switchEthereumChain',
                    params: [params],
                })
                    .catch((error) => {
                    console.error(error);
                    reject(error);
                });
                provider.once('chainChanged', (id) => {
                    if (parseInt(id) === chainId) {
                        resolve(true);
                    }
                    else {
                        resolve(false);
                    }
                });
            });
            return switched;
        }
    }
    catch (error) {
        // const ERROR_CODE_UNKNOWN_CHAIN = 4902
        if (error.code !== sdk_1.MetaMaskProviderErrorCode.userRejectedRequest) {
            const added = await (0, exports.addChain)(provider, chainId);
            return added;
        }
        else {
            console.error(error);
            return false;
        }
    }
};
exports.switchChain = switchChain;
const addChain = async (provider, chainId) => {
    const params = (0, sdk_1.getChainById)(chainId).metamask;
    try {
        if (provider.send) {
            await provider.send('wallet_addEthereumChain', [params]);
        }
        else {
            await provider.request({
                method: 'wallet_addEthereumChain',
                params: [params],
            });
        }
        return true;
    }
    catch (error) {
        console.error(`Error adding chain ${chainId}: ${error.message}`);
        return false;
    }
};
exports.addChain = addChain;
const addToken = async (provider, token) => {
    const params = {
        type: 'ERC20',
        options: {
            address: token.address,
            symbol: token.symbol,
            decimals: token.decimals,
            image: token.logoURI, // A string url of the token logo
        },
    };
    try {
        if (provider.send) {
            await provider.send('wallet_watchAsset', [params]);
        }
        else {
            await provider.request({
                method: 'wallet_watchAsset',
                params: [params],
            });
        }
        return true;
    }
    catch (error) {
        console.error(error);
        return false;
    }
};
exports.addToken = addToken;
const switchChainAndAddToken = async (provider, chainId, token) => {
    const chainIdPrefixed = (0, sdk_1.prefixChainId)(chainId);
    try {
        if (chainIdPrefixed !== (0, sdk_1.prefixChainId)((await provider.getNetwork()).chainId)) {
            const switched = await (0, exports.switchChain)(provider, chainId);
            if (switched) {
                const added = await new Promise((resolve, reject) => {
                    provider.once('chainChanged', async (id) => {
                        if (parseInt(id, 10) === chainId) {
                            const added = await (0, exports.addToken)(provider, token);
                            resolve(added);
                        }
                    });
                });
                return added;
            }
            return switched;
        }
        else {
            const added = await (0, exports.addToken)(provider, token);
            return added;
        }
    }
    catch (error) {
        console.error(error);
        return false;
    }
};
exports.switchChainAndAddToken = switchChainAndAddToken;
