"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.supportedWallets = void 0;
const sdk_1 = require("@lifi/sdk");
const safe_apps_sdk_1 = require("@safe-global/safe-apps-sdk");
const injectedConnector_1 = require("./connectors/injectedConnector");
const safeWalletConnector_1 = require("./connectors/safeWalletConnector");
const walletConnectConnector_1 = require("./connectors/walletConnectConnector");
const types_1 = require("./types");
const walletIcons_1 = require("./walletIcons");
const cyberConnectConnector_1 = require("./connectors/cyberConnectConnector");
const cyber_app_sdk_1 = require("@cyberlab/cyber-app-sdk");
const defaultWallet = new injectedConnector_1.InjectedConnector({
    // unknown Default wallet that injects as metamask but is not metamask
    name: 'Default Wallet',
    installed: async () => !!window.ethereum &&
        !window?.ethereum?.[types_1.ProviderIdentityFlag.MetaMask],
    icon: walletIcons_1.walletIcons.placeholder,
});
const metamask = new injectedConnector_1.InjectedConnector({
    name: 'MetaMask',
    installed: async () => !!window?.ethereum?.[types_1.ProviderIdentityFlag.MetaMask],
    icon: walletIcons_1.walletIcons.metamask,
});
const walletConnect = new walletConnectConnector_1.WalletConnectConnector({
    name: 'WalletConnect',
    installed: async () => true,
    icon: walletIcons_1.walletIcons.walletConnect,
    options: {
        projectId: '5432e3507d41270bee46b7b85bbc2ef8',
        rpcMap: sdk_1.supportedChains.reduce((rpcMap, chain) => {
            if (chain.chainType === sdk_1.ChainType.EVM) {
                rpcMap[`eip155:${chain.id}`] = chain.metamask.rpcUrls[0] || '';
            }
            return rpcMap;
        }, {}),
        chains: [1],
        optionalChains: sdk_1.supportedChains
            .filter((chain) => chain.chainType === sdk_1.ChainType.EVM)
            .map((chain) => chain.id),
        showQrModal: true,
        qrModalOptions: {
            themeVariables: {
                '--wcm-z-index': '3000',
            },
        },
    },
});
const bitGet = new injectedConnector_1.InjectedConnector({
    name: 'Bitget Wallet',
    installed: async () => window.bitkeep && window.bitkeep?.ethereum,
    icon: walletIcons_1.walletIcons.bitGet,
}, window.bitkeep?.ethereum);
const gate = new injectedConnector_1.InjectedConnector({
    name: 'Gate Wallet',
    installed: async () => window.gatewallet,
    icon: walletIcons_1.walletIcons.gate,
}, window.gatewallet);
const frontier = new injectedConnector_1.InjectedConnector({
    name: 'Frontier',
    installed: async () => window.frontier,
    icon: walletIcons_1.walletIcons.frontier,
}, window.frontier?.ethereum);
const safepal = new injectedConnector_1.InjectedConnector({
    name: 'SafePal',
    installed: async () => window.safepal,
    icon: walletIcons_1.walletIcons.safepal,
});
const brave = new injectedConnector_1.InjectedConnector({
    name: 'Brave',
    installed: async () => 
    // eslint-disable-next-line no-underscore-dangle
    navigator.brave && window._web3Ref,
    icon: walletIcons_1.walletIcons.brave,
});
const mathWallet = new injectedConnector_1.InjectedConnector({
    name: 'MathWallet',
    installed: async () => window.ethereum?.[types_1.ProviderIdentityFlag.MathWallet],
    icon: walletIcons_1.walletIcons.mathwallet,
});
const tallyho = new injectedConnector_1.InjectedConnector({
    name: 'Taho',
    installed: async () => window.tally &&
        window.tally?.[types_1.ProviderIdentityFlag.TallyHo],
    icon: walletIcons_1.walletIcons.tallyho,
}, window.tally);
const blockWallet = new injectedConnector_1.InjectedConnector({
    name: 'BlockWallet',
    installed: async () => window.ethereum?.[types_1.ProviderIdentityFlag.BlockWallet],
    icon: walletIcons_1.walletIcons.blockwallet,
});
const binance = new injectedConnector_1.InjectedConnector({
    name: 'Binance',
    installed: async () => window.BinanceChain,
    icon: walletIcons_1.walletIcons.binance,
}, window.BinanceChain);
const coinbase = new injectedConnector_1.InjectedConnector({
    name: 'Coinbase',
    installed: async () => window.coinbaseWalletExtension,
    icon: walletIcons_1.walletIcons.coinbase,
}, window.coinbaseWalletExtension);
const trust = new injectedConnector_1.InjectedConnector({
    name: 'Trust',
    installed: async () => window.trustWallet,
    icon: walletIcons_1.walletIcons.trust,
}, window.trustWallet);
const status = new injectedConnector_1.InjectedConnector({
    name: 'Status',
    installed: async () => window.ethereum?.[types_1.ProviderIdentityFlag.Status],
    icon: walletIcons_1.walletIcons.status,
});
const alphawallet = new injectedConnector_1.InjectedConnector({
    name: 'AlphaWallet',
    installed: async () => window.ethereum?.[types_1.ProviderIdentityFlag.AlphaWallet],
    icon: walletIcons_1.walletIcons.alphawallet,
});
const apex = new injectedConnector_1.InjectedConnector({
    name: 'Apex Wallet',
    installed: async () => window.ethereum?.[types_1.ProviderIdentityFlag.ApexWallet],
    icon: walletIcons_1.walletIcons.placeholder,
});
const bitpie = new injectedConnector_1.InjectedConnector({
    name: 'Bitpie',
    installed: async () => window.ethereum?.Bitpie,
    icon: walletIcons_1.walletIcons.bitpie,
});
const dcent = new injectedConnector_1.InjectedConnector({
    name: 'Dcent',
    installed: async () => window.ethereum?.[types_1.ProviderIdentityFlag.Dcent],
    icon: walletIcons_1.walletIcons.dcent,
});
const frame = new injectedConnector_1.InjectedConnector({
    name: 'Frame',
    installed: async () => window.frame,
    icon: walletIcons_1.walletIcons.frame,
}, window.frame);
const hyperpay = new injectedConnector_1.InjectedConnector({
    name: 'HyperPay',
    // Note: The property `hiWallet` is as of now the only known way of identifying hyperpay
    // wallet as it is a direct clone of metamask. `checkProviderIdentity` implementation is subject to
    // future changes
    installed: async () => window.ethereum?.hiWallet,
    icon: walletIcons_1.walletIcons.hyperpay,
});
const imtoken = new injectedConnector_1.InjectedConnector({
    name: 'ImToken',
    installed: async () => window.ethereum?.[types_1.ProviderIdentityFlag.ImToken],
    icon: walletIcons_1.walletIcons.imtoken,
});
const liquality = new injectedConnector_1.InjectedConnector({
    name: 'Liquality',
    installed: async () => window.liquality,
    icon: walletIcons_1.walletIcons.liquality,
}, window.liquality);
const ownbit = new injectedConnector_1.InjectedConnector({
    name: 'OwnBit',
    installed: async () => window.ethereum?.[types_1.ProviderIdentityFlag.OwnBit],
    icon: walletIcons_1.walletIcons.ownbit,
});
const tokenpocket = new injectedConnector_1.InjectedConnector({
    name: 'TokenPocket',
    installed: async () => window.ethereum?.[types_1.ProviderIdentityFlag.TokenPocket] &&
        !window.ethereum?.[types_1.ProviderIdentityFlag.TP],
    icon: walletIcons_1.walletIcons.tokenpocket,
});
const xdefi = new injectedConnector_1.InjectedConnector({
    name: 'XDEFI',
    // eslint-disable-next-line dot-notation
    installed: async () => window.ethereum?.[types_1.ProviderIdentityFlag.XDEFI],
    icon: walletIcons_1.walletIcons.xdefi,
});
const oneInch = new injectedConnector_1.InjectedConnector({
    name: 'OneInch',
    installed: async () => window.ethereum?.[types_1.ProviderIdentityFlag.OneInch],
    icon: walletIcons_1.walletIcons.oneInch,
});
const tokenary = new injectedConnector_1.InjectedConnector({
    name: 'Tokenary',
    installed: async () => window.ethereum?.[types_1.ProviderIdentityFlag.Tokenary],
    icon: walletIcons_1.walletIcons.tokenary,
});
const okx = new injectedConnector_1.InjectedConnector({
    name: 'OKX',
    installed: async () => window.okxwallet,
    icon: walletIcons_1.walletIcons.okx,
}, window.okxwallet);
const rabbywallet = new injectedConnector_1.InjectedConnector({
    name: 'Rabby Wallet',
    installed: async () => window.rabby,
    icon: walletIcons_1.walletIcons.rabbywallet,
}, window.rabby);
const exodus = new injectedConnector_1.InjectedConnector({
    name: 'Exodus',
    installed: async () => window.exodus?.ethereum,
    icon: walletIcons_1.walletIcons.exodus,
}, window.exodus?.ethereum);
const safe = new safeWalletConnector_1.SafeWalletConnector({
    name: 'Safe',
    installed: async () => {
        // in Multisig env, window.parent is not equal to window
        const isIFrameEnvironment = window?.parent !== window;
        if (!isIFrameEnvironment) {
            return false;
        }
        const sdk = new safe_apps_sdk_1.default();
        try {
            const accountInfo = await Promise.race([
                sdk.safe.getInfo(),
                new Promise((resolve) => setTimeout(resolve, 200)),
            ]);
            return !!accountInfo?.safeAddress;
        }
        catch (error) {
            return false;
        }
    },
    icon: walletIcons_1.walletIcons.safe,
});
const cyberConnect = new cyberConnectConnector_1.CyberConnectConnector({
    name: 'CyberConnect',
    installed: async () => (0, cyber_app_sdk_1.isCyberWallet)(),
    icon: walletIcons_1.walletIcons.cyberconnect,
});
exports.supportedWallets = [
    defaultWallet,
    safe,
    metamask,
    walletConnect,
    bitGet,
    gate,
    exodus,
    tallyho,
    binance,
    frontier,
    coinbase,
    okx,
    trust,
    status,
    alphawallet,
    blockWallet,
    bitpie,
    brave,
    apex,
    dcent,
    frame,
    hyperpay,
    imtoken,
    liquality,
    ownbit,
    tokenpocket,
    xdefi,
    oneInch,
    tokenary,
    mathWallet,
    cyberConnect,
    safepal,
    rabbywallet,
];
