import { Web3Provider } from '@ethersproject/providers';
import { SafeAppProvider } from '@safe-global/safe-apps-provider';
import SafeAppsSDK from '@safe-global/safe-apps-sdk';
import { EventEmitter } from 'events';
export class SafeWalletConnector extends EventEmitter {
    constructor(args) {
        super();
        this.isActivationInProgress = false;
        this.autoConnect = async () => {
            await this.calcAccountData();
        };
        this.disconnect = () => {
            this.account = undefined;
        };
        this.connect = async () => {
            await this.calcAccountData();
        };
        this.switchChain = () => {
            console.warn('Method switchChain not allowed');
            return null;
        };
        this.addChain = () => {
            console.warn('Method addChain not allowed');
            return null;
        };
        this.addToken = () => {
            console.warn('Method addToken not allowed');
            return null;
        };
        this.name = args.name;
        this.icon = args.icon;
        this.installed = args.installed;
        this.calcAccountData();
    }
    async calcAccountData() {
        const sdk = new SafeAppsSDK();
        const accountInfo = await sdk.safe.getInfo();
        const safe = {
            safeAddress: accountInfo.safeAddress,
            chainId: accountInfo.chainId,
            threshold: accountInfo.threshold,
            owners: accountInfo.owners,
            isReadOnly: accountInfo.isReadOnly,
        };
        const safeInstance = new SafeAppProvider(safe, sdk);
        const provider = new Web3Provider(safeInstance);
        const signer = provider.getSigner();
        this.account = {
            chainId: accountInfo.chainId,
            address: accountInfo.safeAddress,
            signer,
            provider,
            isMultisigWallet: true,
        };
        this.emit('walletAccountChanged', this);
    }
}
