import { Web3Provider } from '@ethersproject/providers';
import WalletConnectProvider from '@walletconnect/ethereum-provider';
import { EventEmitter } from 'events';
import { addChain, switchChain, switchChainAndAddToken, } from '../walletAutomation';
export class WalletConnectConnector extends EventEmitter {
    constructor(args) {
        super();
        this.isActivationInProgress = false;
        this.options = args.options;
        this.name = args.name;
        this.icon = args.icon;
        this.installed = args.installed;
    }
    async startListening() {
        // Subscribe to accounts change
        this.provider?.on('accountsChanged', async (accounts) => {
            if (!accounts.length) {
                this.account = undefined;
                this.emit('walletAccountChanged', this);
                return;
            }
            await this.calcAccountData();
        });
        // Subscribe to chainId change
        this.provider?.on('chainChanged', async (chainId) => {
            await this.calcAccountData();
        });
        // Subscribe to session disconnection
        this.provider?.on('disconnect', async (code, reason) => {
            // await this.calcAccountData();
        });
    }
    async connect() {
        if (this.isActivationInProgress) {
            return;
        }
        this.isActivationInProgress = true;
        this.walletConnectProvider || (this.walletConnectProvider = await WalletConnectProvider.init(this.options));
        this.provider = this
            .walletConnectProvider;
        try {
            // Open modal
            await this.walletConnectProvider?.enable();
            this.startListening();
            await this.calcAccountData();
        }
        catch (e) {
            this.isActivationInProgress = false;
            throw e;
        }
        this.isActivationInProgress = false;
    }
    async disconnect() {
        if (this.provider) {
            await this.provider?.disconnect();
            await this.walletConnectProvider?.disconnect();
            this.provider = undefined;
            this.walletConnectProvider = undefined;
            this.isActivationInProgress = false;
            this.account = undefined;
            this.emit('walletAccountChanged', this);
        }
    }
    async switchChain(chainId) {
        if (!this.provider) {
            throw new Error('Provider is not defined.');
        }
        return switchChain(this.walletConnectProvider, chainId);
    }
    async addChain(chainId) {
        if (!this.provider) {
            throw new Error('Provider is not defined.');
        }
        return addChain(this.walletConnectProvider, chainId);
    }
    async addToken(chainId, token) {
        if (!this.provider) {
            throw new Error('Provider is not defined.');
        }
        return switchChainAndAddToken(this.walletConnectProvider, chainId, token);
    }
    async calcAccountData() {
        if (!this.walletConnectProvider) {
            throw new Error('Provider is not defined.');
        }
        const provider = new Web3Provider(this.walletConnectProvider, 'any');
        const signer = provider.getSigner();
        this.account = {
            chainId: await signer.getChainId(),
            address: await signer.getAddress(),
            signer,
            provider,
        };
        this.emit('walletAccountChanged', this);
    }
}
