import { MetaMaskProviderErrorCode, getChainById, prefixChainId, } from '@lifi/sdk';
export const switchChain = async (provider, chainId) => {
    const params = { chainId: getChainById(chainId).metamask?.chainId };
    try {
        if (provider.send) {
            await provider.send('wallet_switchEthereumChain', [params]);
            return true;
        }
        else {
            const switched = await new Promise((resolve, reject) => {
                provider
                    .request({
                    method: 'wallet_switchEthereumChain',
                    params: [params],
                })
                    .catch((error) => {
                    console.error(error);
                    reject(error);
                });
                provider.once('chainChanged', (id) => {
                    if (parseInt(id) === chainId) {
                        resolve(true);
                    }
                    else {
                        resolve(false);
                    }
                });
            });
            return switched;
        }
    }
    catch (error) {
        // const ERROR_CODE_UNKNOWN_CHAIN = 4902
        if (error.code !== MetaMaskProviderErrorCode.userRejectedRequest) {
            const added = await addChain(provider, chainId);
            return added;
        }
        else {
            console.error(error);
            return false;
        }
    }
};
export const addChain = async (provider, chainId) => {
    const params = getChainById(chainId).metamask;
    try {
        if (provider.send) {
            await provider.send('wallet_addEthereumChain', [params]);
        }
        else {
            await provider.request({
                method: 'wallet_addEthereumChain',
                params: [params],
            });
        }
        return true;
    }
    catch (error) {
        console.error(`Error adding chain ${chainId}: ${error.message}`);
        return false;
    }
};
export const addToken = async (provider, token) => {
    const params = {
        type: 'ERC20',
        options: {
            address: token.address,
            symbol: token.symbol,
            decimals: token.decimals,
            image: token.logoURI, // A string url of the token logo
        },
    };
    try {
        if (provider.send) {
            await provider.send('wallet_watchAsset', [params]);
        }
        else {
            await provider.request({
                method: 'wallet_watchAsset',
                params: [params],
            });
        }
        return true;
    }
    catch (error) {
        console.error(error);
        return false;
    }
};
export const switchChainAndAddToken = async (provider, chainId, token) => {
    const chainIdPrefixed = prefixChainId(chainId);
    try {
        if (chainIdPrefixed !== prefixChainId((await provider.getNetwork()).chainId)) {
            const switched = await switchChain(provider, chainId);
            if (switched) {
                const added = await new Promise((resolve, reject) => {
                    provider.once('chainChanged', async (id) => {
                        if (parseInt(id, 10) === chainId) {
                            const added = await addToken(provider, token);
                            resolve(added);
                        }
                    });
                });
                return added;
            }
            return switched;
        }
        else {
            const added = await addToken(provider, token);
            return added;
        }
    }
    catch (error) {
        console.error(error);
        return false;
    }
};
