import { ChainType, supportedChains } from '@lifi/sdk';
import SafeAppsSDK from '@safe-global/safe-apps-sdk';
import { InjectedConnector } from './connectors/injectedConnector';
import { SafeWalletConnector } from './connectors/safeWalletConnector';
import { WalletConnectConnector } from './connectors/walletConnectConnector';
import { ProviderIdentityFlag } from './types';
import { walletIcons } from './walletIcons';
import { CyberConnectConnector } from './connectors/cyberConnectConnector';
import { isCyberWallet } from '@cyberlab/cyber-app-sdk';
const defaultWallet = new InjectedConnector({
    // unknown Default wallet that injects as metamask but is not metamask
    name: 'Default Wallet',
    installed: async () => !!window.ethereum &&
        !window?.ethereum?.[ProviderIdentityFlag.MetaMask],
    icon: walletIcons.placeholder,
});
const metamask = new InjectedConnector({
    name: 'MetaMask',
    installed: async () => !!window?.ethereum?.[ProviderIdentityFlag.MetaMask],
    icon: walletIcons.metamask,
});
const walletConnect = new WalletConnectConnector({
    name: 'WalletConnect',
    installed: async () => true,
    icon: walletIcons.walletConnect,
    options: {
        projectId: '5432e3507d41270bee46b7b85bbc2ef8',
        rpcMap: supportedChains.reduce((rpcMap, chain) => {
            if (chain.chainType === ChainType.EVM) {
                rpcMap[`eip155:${chain.id}`] = chain.metamask.rpcUrls[0] || '';
            }
            return rpcMap;
        }, {}),
        chains: [1],
        optionalChains: supportedChains
            .filter((chain) => chain.chainType === ChainType.EVM)
            .map((chain) => chain.id),
        showQrModal: true,
        qrModalOptions: {
            themeVariables: {
                '--wcm-z-index': '3000',
            },
        },
    },
});
const bitGet = new InjectedConnector({
    name: 'Bitget Wallet',
    installed: async () => window.bitkeep && window.bitkeep?.ethereum,
    icon: walletIcons.bitGet,
}, window.bitkeep?.ethereum);
const gate = new InjectedConnector({
    name: 'Gate Wallet',
    installed: async () => window.gatewallet,
    icon: walletIcons.gate,
}, window.gatewallet);
const frontier = new InjectedConnector({
    name: 'Frontier',
    installed: async () => window.frontier,
    icon: walletIcons.frontier,
}, window.frontier?.ethereum);
const safepal = new InjectedConnector({
    name: 'SafePal',
    installed: async () => window.safepal,
    icon: walletIcons.safepal,
});
const brave = new InjectedConnector({
    name: 'Brave',
    installed: async () => 
    // eslint-disable-next-line no-underscore-dangle
    navigator.brave && window._web3Ref,
    icon: walletIcons.brave,
});
const mathWallet = new InjectedConnector({
    name: 'MathWallet',
    installed: async () => window.ethereum?.[ProviderIdentityFlag.MathWallet],
    icon: walletIcons.mathwallet,
});
const tallyho = new InjectedConnector({
    name: 'Taho',
    installed: async () => window.tally &&
        window.tally?.[ProviderIdentityFlag.TallyHo],
    icon: walletIcons.tallyho,
}, window.tally);
const blockWallet = new InjectedConnector({
    name: 'BlockWallet',
    installed: async () => window.ethereum?.[ProviderIdentityFlag.BlockWallet],
    icon: walletIcons.blockwallet,
});
const binance = new InjectedConnector({
    name: 'Binance',
    installed: async () => window.BinanceChain,
    icon: walletIcons.binance,
}, window.BinanceChain);
const coinbase = new InjectedConnector({
    name: 'Coinbase',
    installed: async () => window.coinbaseWalletExtension,
    icon: walletIcons.coinbase,
}, window.coinbaseWalletExtension);
const trust = new InjectedConnector({
    name: 'Trust',
    installed: async () => window.trustWallet,
    icon: walletIcons.trust,
}, window.trustWallet);
const status = new InjectedConnector({
    name: 'Status',
    installed: async () => window.ethereum?.[ProviderIdentityFlag.Status],
    icon: walletIcons.status,
});
const alphawallet = new InjectedConnector({
    name: 'AlphaWallet',
    installed: async () => window.ethereum?.[ProviderIdentityFlag.AlphaWallet],
    icon: walletIcons.alphawallet,
});
const apex = new InjectedConnector({
    name: 'Apex Wallet',
    installed: async () => window.ethereum?.[ProviderIdentityFlag.ApexWallet],
    icon: walletIcons.placeholder,
});
const bitpie = new InjectedConnector({
    name: 'Bitpie',
    installed: async () => window.ethereum?.Bitpie,
    icon: walletIcons.bitpie,
});
const dcent = new InjectedConnector({
    name: 'Dcent',
    installed: async () => window.ethereum?.[ProviderIdentityFlag.Dcent],
    icon: walletIcons.dcent,
});
const frame = new InjectedConnector({
    name: 'Frame',
    installed: async () => window.frame,
    icon: walletIcons.frame,
}, window.frame);
const hyperpay = new InjectedConnector({
    name: 'HyperPay',
    // Note: The property `hiWallet` is as of now the only known way of identifying hyperpay
    // wallet as it is a direct clone of metamask. `checkProviderIdentity` implementation is subject to
    // future changes
    installed: async () => window.ethereum?.hiWallet,
    icon: walletIcons.hyperpay,
});
const imtoken = new InjectedConnector({
    name: 'ImToken',
    installed: async () => window.ethereum?.[ProviderIdentityFlag.ImToken],
    icon: walletIcons.imtoken,
});
const liquality = new InjectedConnector({
    name: 'Liquality',
    installed: async () => window.liquality,
    icon: walletIcons.liquality,
}, window.liquality);
const ownbit = new InjectedConnector({
    name: 'OwnBit',
    installed: async () => window.ethereum?.[ProviderIdentityFlag.OwnBit],
    icon: walletIcons.ownbit,
});
const tokenpocket = new InjectedConnector({
    name: 'TokenPocket',
    installed: async () => window.ethereum?.[ProviderIdentityFlag.TokenPocket] &&
        !window.ethereum?.[ProviderIdentityFlag.TP],
    icon: walletIcons.tokenpocket,
});
const xdefi = new InjectedConnector({
    name: 'XDEFI',
    // eslint-disable-next-line dot-notation
    installed: async () => window.ethereum?.[ProviderIdentityFlag.XDEFI],
    icon: walletIcons.xdefi,
});
const oneInch = new InjectedConnector({
    name: 'OneInch',
    installed: async () => window.ethereum?.[ProviderIdentityFlag.OneInch],
    icon: walletIcons.oneInch,
});
const tokenary = new InjectedConnector({
    name: 'Tokenary',
    installed: async () => window.ethereum?.[ProviderIdentityFlag.Tokenary],
    icon: walletIcons.tokenary,
});
const okx = new InjectedConnector({
    name: 'OKX',
    installed: async () => window.okxwallet,
    icon: walletIcons.okx,
}, window.okxwallet);
const rabbywallet = new InjectedConnector({
    name: 'Rabby Wallet',
    installed: async () => window.rabby,
    icon: walletIcons.rabbywallet,
}, window.rabby);
const exodus = new InjectedConnector({
    name: 'Exodus',
    installed: async () => window.exodus?.ethereum,
    icon: walletIcons.exodus,
}, window.exodus?.ethereum);
const safe = new SafeWalletConnector({
    name: 'Safe',
    installed: async () => {
        // in Multisig env, window.parent is not equal to window
        const isIFrameEnvironment = window?.parent !== window;
        if (!isIFrameEnvironment) {
            return false;
        }
        const sdk = new SafeAppsSDK();
        try {
            const accountInfo = await Promise.race([
                sdk.safe.getInfo(),
                new Promise((resolve) => setTimeout(resolve, 200)),
            ]);
            return !!accountInfo?.safeAddress;
        }
        catch (error) {
            return false;
        }
    },
    icon: walletIcons.safe,
});
const cyberConnect = new CyberConnectConnector({
    name: 'CyberConnect',
    installed: async () => isCyberWallet(),
    icon: walletIcons.cyberconnect,
});
export const supportedWallets = [
    defaultWallet,
    safe,
    metamask,
    walletConnect,
    bitGet,
    gate,
    exodus,
    tallyho,
    binance,
    frontier,
    coinbase,
    okx,
    trust,
    status,
    alphawallet,
    blockWallet,
    bitpie,
    brave,
    apex,
    dcent,
    frame,
    hyperpay,
    imtoken,
    liquality,
    ownbit,
    tokenpocket,
    xdefi,
    oneInch,
    tokenary,
    mathWallet,
    cyberConnect,
    safepal,
    rabbywallet,
];
